CREATE OR REPLACE PROCEDURE ARQUIVO_CURITIBA_ISS(
   P_NRLISTA     IN NOTAFISCAL.NRLANCTONF%TYPE,
   P_CDEMPRESA   IN NOTAFISCAL.CDEMPRESA%TYPE,
   P_NRSEQARQMAG IN NOTAFISCAL.NRLANCTONF%TYPE)
AS
   V_CONTADOR    NUMBER;
   V_REGH        VARCHAR2(400);
   V_REGT        VARCHAR2(400);
   V_VRTOTEMIT   NUMBER;
   V_VRDEDEMIT   NUMBER;
   V_VRTOTRECE   NUMBER;
   V_VRDEDRECE   NUMBER;
BEGIN
   V_CONTADOR := 0;

   /*REGISTRO HEADER*/
   BEGIN
      SELECT MAX('H'                                                                ||
             LPAD(NF.CDINSCMUNI,10,'0')                                             || /*Insc. Municipal do declarante*/
             LPAD(DECODE(LENGTH(IM.NRINSJURIMUNI),14,IM.NRINSJURIMUNI,'0'),14,'0')  || /*CNPJ do declarante*/
             LPAD(DECODE(LENGTH(IM.NRINSJURIMUNI),11,IM.NRINSJURIMUNI,'0'),11,'0')  || /*CPF do declarante*/
             RPAD(EP.NMRAZSOCEMPR,100,' ')                                          || /*Razo Social do declarante*/
             'N'/*PARA VALIDAR O ARQUIVO MUDE A LETRA MANUALMENTE PARA T*/          || /*Tipo do arquivo: N-Normal / T-Teste*/
             TO_CHAR(DECODE(NF.IDENTRSAIDOP,'E',NF.DTENTRSAID,NF.DTEMISSAO),'MM')   || /*Mes de referencia*/
             TO_CHAR(DECODE(NF.IDENTRSAIDOP,'E',NF.DTENTRSAID,NF.DTEMISSAO),'YYYY') || /*Ano de referencia*/
             RPAD(' ',252,' ')                                                      || /*Brancos*/
             '.')                                                                      /*Indicador de final do registro*/
        INTO V_REGH
        FROM LISTA LS, NOTAFISCAL NF, EMPRESA EP, INSCRMUNICIP IM
       WHERE LS.NRLISTA    = P_NRLISTA
         AND LS.CDLISTA    = NF.CDFILIAL||NF.NRLANCTONF
         AND NF.CDEMPRESA  = EP.CDEMPRESA
         AND NF.CDEMPRESA  = IM.CDEMPRESA
         AND NF.CDINSCMUNI = IM.CDINSCMUNI;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_REGH := 'H'||LPAD('0',35,'0')||RPAD(' ',101,' ')||LPAD('0',6,'0')||RPAD(' ',252,' ')||'.';
   END;

   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
    VALUES
      ('1'||LPAD(V_CONTADOR,9,'0'), V_REGH , P_NRSEQARQMAG);
   V_CONTADOR := NVL(V_CONTADOR,0)+1;

   /*REGISTRO DOCUMENTOS EMITIDOS CANCELADOS*/
   FOR C_REGC IN (SELECT 'C'                                                               ||
                         TO_CHAR(NF.DTCANCELANF,'DDMMYYYY')                                || /*Data do Cancelamento*/
                         LPAD(NF.NRNOTAFISC,8,'0')                                         || /*Nmero da Nota Inicial*/
                         LPAD('0',8,'0')                                                   || /*Nmero da Nota Final*/
                         RPAD(DECODE(NF.IDENTRSAIDOP,'E',NF.CDSERIEENTR,NF.CDSERIE),3,' ') || /*Srie*/
                         LPAD(' ',361,' ')                                                 || /*Reservado*/
                         LPAD(V_CONTADOR,6,'0')                                            || /*Sequencial*/
                         '.'                AS DADOS,                                         /*Indicador de final do arquivo*/
                         NF.CDFILIAL, NF.NRLANCTONF
                    FROM LISTA LS, NOTAFISCAL NF
                   WHERE LS.NRLISTA      = P_NRLISTA
                     AND LS.CDLISTA      = NF.CDFILIAL||NF.NRLANCTONF
                     AND NF.IDSTATUSNFE = 'C'
                   ORDER BY NF.NRNOTAFISC) LOOP

      INSERT INTO ARQMAGNETICO
         (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
       VALUES
         ('2'||LPAD(V_CONTADOR,9,'0'), C_REGC.DADOS , P_NRSEQARQMAG);
      V_CONTADOR := NVL(V_CONTADOR,0)+1;

      UPDATE NOTAFISCAL
         SET IDEXPNFEISS = 'S'
       WHERE CDFILIAL    = C_REGC.CDFILIAL
         AND NRLANCTONF  = C_REGC.NRLANCTONF;

   END LOOP;

   /*REGISTRO DOCUMENTOS EMITIDOS DECLARADOS*/
   FOR C_REGE IN (SELECT 'E'                                                    ||
                         TO_CHAR(N.DTEMISSAO,'DDMMYYYY')                        || /*Data de Emissao*/
                         SUBSTR(LPAD(N.NRNOTAFISC,20,'0'),13,8)                 || /*Nmero da Nota Inicial*/
                         LPAD('0',8,'0')                                        || /*Nmero da Nota Final*/
                         N.CDTIPODOC                                            || /*Tipo Documento: 1-NF; 2-Recibo; 3-RPA; 4-ECF; 6-NFCT*/
                         RPAD(NVL(N.CDSERIE,' '),3,' ')                         || /*Srie - somente NF*/
                         DECODE(N.VRISSRET,0,'N','S')                           || /*Identificao do Servio: S-Servio ST/Ret; N-Doc. Fiscal Normal*/
                         DECODE(N.CDMUNIORIG,N.CDMUNIDEST,'D','F')              || /*Local de Prestao - somente Servio ST/Ret*/
                         RPAD(NVL(SUBSTR(C.CDCLASSERVPADR,1,2),' '),2,' ')      || /*Cdigo Item - somente Servio ST/Ret*/
                         RPAD(NVL(SUBSTR(C.CDCLASSERVPADR,3,2),' '),2,' ')      || /*Cdito Sub-Item - somente Servio ST/Ret*/
                         LPAD(REPLACE(ROUND(SUM(NVL(N.VRCONTITEM,0)),2),',',''),15,'0')|| /*Valor Documento*/
                         LPAD('0',15,'0')                                       || /*Valor Deduo*/
                         LPAD(NVL(N.NRINSCMUNI,'0'),10,'0')                     || /*Insc. Municipal do tomador*/
                         LPAD(DECODE(N.IDTIPOJUR,'J',N.NRINSCJUR,'0'),14,'0')   || /*CNPJ do tomador*/
                         LPAD(DECODE(N.IDTIPOJUR,'F',N.NRINSCJUR,'0'),11,'0')   || /*CPF do tomador*/
                         RPAD(NVL(N.NMRAZSOC,' '),100,' ')                      || /*Nome do tomador*/
                         '     '                                                || /*Tipo Logradouro do endereo do tomador*/
                         RPAD(NVL(N.DSLOGRAD,' '),50,' ')                       || /*Nome Logradouro do endereo do tomador*/
                         '000000'                                               || /*Nmero do endereo do tomador*/
                         RPAD(NVL(N.DSCOMPLE,' '),20,' ')                       || /*Complemento do endereo do tomador*/
                         RPAD(NVL(N.NMBAIRRO,' '),50,' ')                       || /*Bairro do endereo do tomador*/
                         RPAD(NVL(N.NMMUNICIPIO,' '),44,' ')                    || /*Cidade do endereo do tomador*/
                         N.SGESTADO                                             || /*Estado do endereo do tomador*/
                         LPAD(REPLACE(NVL(N.CEP,'0'),'-',''),8,'0')             || /*CEP do endereo do tomador*/
                         LPAD(V_CONTADOR,6,'0')                                 || /*Sequencial*/
                         LPAD(REPLACE(ROUND(NVL(DECODE(N.VRISSRET,0,0,N.ALIQISSRET),0),2),',',''),4,'0') || /*Alquota*/
                         '.'                                                     AS DADOS, /*Indicador de final do arquivo*/
                         SUM(NVL(N.VRCONTITEM,0)) AS VRCONTITEM, N.VRNOTAFISC, N.NRLANCTONF, N.CDFILIAL
                    FROM CODTRIBPRODPADR C,
                         (SELECT NF.CDFILIAL, NF.NRLANCTONF, NF.DTEMISSAO, NF.NRNOTAFISC, NF.CDSERIE, NF.VRNOTAFISC, EN.SGESTADO||EN.CDMUNICIPIO AS CDMUNIORIG,
                                 CASE WHEN NF.CDMODDOCFISC = '2D' THEN '4' WHEN NF.CDMODDOCFISC IN ('08','09','10','11','26','57') THEN '6' ELSE '1' END AS CDTIPODOC,
                                 CL.NRINSMUNICLIE AS NRINSCMUNI, CL.IDTPIJURCLIE AS IDTIPOJUR, CL.NRINSJURCLIE AS NRINSCJUR, CL.NMRAZSOCCLIE AS NMRAZSOC,
                                 EC.DSENDECLIE AS DSLOGRAD, EC.DSCOMPENDCLI AS DSCOMPLE, EC.NMBAIRCLIE AS NMBAIRRO, MP.NMMUNICIPIO, EC.SGESTADO, EC.NRCEPCLIE AS CEP,
                                 EC.SGESTADO||EC.CDMUNICIPIO AS CDMUNIDEST, NF.CDEMPRESA, NF.CDINSCMUNI, IP.CDPRODUTO,
                                 SUM(VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL,IT.NRLANCTONF,IT.NRSEQITPROD,'36','C','1')) AS VRCONTITEM,
                                 SUM(VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL,IT.NRLANCTONF,IT.NRSEQITPROD,'36','I','1')) AS VRISSRET,
                                 VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL,IT.NRLANCTONF,IT.NRSEQITPROD,'36','A','1') AS ALIQISSRET
                            FROM LISTA LS, NOTAFISCAL NF, ENDEFILI EN, CLIENTE CL, ENDECLIE EC, MUNICIPIO MP, ITEMPROIMPOS IT, ITEMPRODUTO IP
                           WHERE LS.NRLISTA      = P_NRLISTA
                             AND LS.CDLISTA      = NF.CDFILIAL||NF.NRLANCTONF
                             AND NF.IDSTATUSNFE <> 'C'
                             AND NF.IDENTRSAIDOP = 'S'
                             AND NF.CDFILIEMIT   = EN.CDFILIAL
                             AND NVL(EN.IDTPENDEFILI,'P') = 'P'
                             AND NF.IDORIGDESTNF = 'C'
                             AND NF.CDCLIENTE    = CL.CDCLIENTE(+)
                             AND CL.CDCLIENTE    = EC.CDCLIENTE(+)
                             AND NVL(EC.IDTPENDECLIE(+),'P') = 'P'
                             AND EC.CDPAIS       = MP.CDPAIS(+)
                             AND EC.SGESTADO     = MP.SGESTADO(+)
                             AND EC.CDMUNICIPIO  = MP.CDMUNICIPIO(+)
                             AND NF.CDFILIAL     = IT.CDFILIAL
                             AND NF.NRLANCTONF   = IT.NRLANCTONF
                             AND IT.CDFILIAL     = IP.CDFILIAL
                             AND IT.NRLANCTONF   = IP.NRLANCTONF
                             AND IT.NRSEQITPROD  = IP.NRSEQITPROD
                           GROUP BY NF.CDFILIAL, NF.NRLANCTONF, NF.DTEMISSAO, NF.NRNOTAFISC, NF.CDSERIE, NF.VRNOTAFISC, EN.SGESTADO||EN.CDMUNICIPIO,
                                 CASE WHEN NF.CDMODDOCFISC = '2D' THEN '4' WHEN NF.CDMODDOCFISC IN ('08','09','10','11','26','57') THEN '6' ELSE '1' END,
                                 CL.NRINSMUNICLIE, CL.IDTPIJURCLIE, CL.NRINSJURCLIE, CL.NMRAZSOCCLIE, NF.CDEMPRESA, NF.CDINSCMUNI, IP.CDPRODUTO,
                                 EC.DSENDECLIE, EC.DSCOMPENDCLI, EC.NMBAIRCLIE, MP.NMMUNICIPIO, EC.SGESTADO, EC.NRCEPCLIE, EC.SGESTADO||EC.CDMUNICIPIO,
                                 VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL,IT.NRLANCTONF,IT.NRSEQITPROD,'36','A','1')
                          UNION ALL
                          SELECT NF.CDFILIAL, NF.NRLANCTONF, NF.DTEMISSAO, NF.NRNOTAFISC, NF.CDSERIE, NF.VRNOTAFISC, EN.SGESTADO||EN.CDMUNICIPIO,
                                 CASE WHEN NF.CDMODDOCFISC = '2D' THEN '4' WHEN NF.CDMODDOCFISC IN ('08','09','10','11','26','57') THEN '6' ELSE '1' END AS CDTIPODOC,
                                 FI.CDINSCMUNI AS NRINSCMUNI, FI.IDTPIJURFILI AS IDTIPOJUR, FI.NRINSJURFILI AS NRINSCJUR, FI.NMRAZSOCFILI AS NMRAZSOC,
                                 EL.DSENDEFILI AS DSLOGRAD, EL.DSCOMPENDFIL AS DSCOMPLE, EL.NMBAIRFILI AS NMBAIRRO, MP.NMMUNICIPIO, EL.SGESTADO, EL.NRCEPFILI AS CEP,
                                 EL.SGESTADO||EL.CDMUNICIPIO AS CDMUNIDEST, NF.CDEMPRESA, NF.CDINSCMUNI, IP.CDPRODUTO,
                                 SUM(VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL,IT.NRLANCTONF,IT.NRSEQITPROD,'35','C','1')) AS VRCONTITEM,
                                 SUM(VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL,IT.NRLANCTONF,IT.NRSEQITPROD,'35','I','1')) AS VRISSRET,
                                 VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL,IT.NRLANCTONF,IT.NRSEQITPROD,'35','A','1') AS ALIQISSRET
                            FROM LISTA LS, NOTAFISCAL NF, ENDEFILI EN, FILIAL FI, ENDEFILI EL, MUNICIPIO MP, ITEMPROIMPOS IT, ITEMPRODUTO IP
                           WHERE LS.NRLISTA      = P_NRLISTA
                             AND LS.CDLISTA      = NF.CDFILIAL||NF.NRLANCTONF
                             AND NF.IDSTATUSNFE <> 'C'
                             AND NF.IDENTRSAIDOP = 'S'
                             AND NF.CDFILIEMIT   = EN.CDFILIAL
                             AND NVL(EN.IDTPENDEFILI,'P') = 'P'
                             AND NF.IDORIGDESTNF = 'L'
                             AND NF.CDFILIRECE   = FI.CDFILIAL(+)
                             AND FI.CDFILIAL     = EL.CDFILIAL(+)
                             AND NVL(EL.IDTPENDEFILI(+),'P') = 'P'
                             AND EL.CDPAIS       = MP.CDPAIS(+)
                             AND EL.SGESTADO     = MP.SGESTADO(+)
                             AND EL.CDMUNICIPIO  = MP.CDMUNICIPIO(+)
                             AND NF.CDFILIAL     = IT.CDFILIAL
                             AND NF.NRLANCTONF   = IT.NRLANCTONF
                             AND IT.CDFILIAL     = IP.CDFILIAL
                             AND IT.NRLANCTONF   = IP.NRLANCTONF
                             AND IT.NRSEQITPROD  = IP.NRSEQITPROD
                           GROUP BY NF.CDFILIAL, NF.NRLANCTONF, NF.DTEMISSAO, NF.NRNOTAFISC, NF.CDSERIE, NF.VRNOTAFISC, EN.SGESTADO||EN.CDMUNICIPIO,
                                 CASE WHEN NF.CDMODDOCFISC = '2D' THEN '4' WHEN NF.CDMODDOCFISC IN ('08','09','10','11','26','57') THEN '6' ELSE '1' END,
                                 FI.CDINSCMUNI, FI.IDTPIJURFILI, FI.NRINSJURFILI, FI.NMRAZSOCFILI, NF.CDEMPRESA, NF.CDINSCMUNI, IP.CDPRODUTO,
                                 EL.DSENDEFILI, EL.DSCOMPENDFIL, EL.NMBAIRFILI, MP.NMMUNICIPIO, EL.SGESTADO, EL.NRCEPFILI, EL.SGESTADO||EL.CDMUNICIPIO,
                                 VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL,IT.NRLANCTONF,IT.NRSEQITPROD,'35','A','1')) N
                   WHERE N.CDEMPRESA  = C.CDEMPRESA(+)
                     AND N.CDINSCMUNI = C.CDINSCMUNI(+)
                     AND N.CDPRODUTO  = C.CDPRODUTO(+)
                   GROUP BY 'E',
                            TO_CHAR(N.DTEMISSAO,'DDMMYYYY'),
                            N.NRNOTAFISC,
                            N.CDTIPODOC,
                            N.CDSERIE,
                            DECODE(N.VRISSRET,0,'N','S'),
                            DECODE(N.CDMUNIORIG,N.CDMUNIDEST,'D','F'),
                            SUBSTR(C.CDCLASSERVPADR,1,2),
                            SUBSTR(C.CDCLASSERVPADR,3,2),
                            LPAD('0',15,'0'),
                            N.NRINSCMUNI,
                            DECODE(N.IDTIPOJUR,'J',N.NRINSCJUR,'0'),
                            DECODE(N.IDTIPOJUR,'F',N.NRINSCJUR,'0'),
                            N.NMRAZSOC,
                            N.DSLOGRAD,
                            N.DSCOMPLE,
                            N.NMBAIRRO,
                            N.NMMUNICIPIO,
                            N.SGESTADO,
                            N.CEP,
                            V_CONTADOR,
                            DECODE(N.VRISSRET,0,0,N.ALIQISSRET),
                            N.VRNOTAFISC, N.NRLANCTONF, N.CDFILIAL
                   ORDER BY N.NRNOTAFISC) LOOP

      INSERT INTO ARQMAGNETICO
         (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
       VALUES
         ('3'||LPAD(V_CONTADOR,9,'0'), C_REGE.DADOS , P_NRSEQARQMAG);
      V_CONTADOR := NVL(V_CONTADOR,0)+1;

      V_VRTOTEMIT := NVL(V_VRTOTEMIT,0) + C_REGE.VRCONTITEM;
      V_VRDEDEMIT := 0;

      UPDATE NOTAFISCAL
         SET IDEXPNFEISS = 'S'
       WHERE CDFILIAL    = C_REGE.CDFILIAL
         AND NRLANCTONF  = C_REGE.NRLANCTONF;

   END LOOP;

   /*REGISTRO DOCUMENTOS RECEBIDOS DECLARADOS*/
   FOR C_REGR IN (SELECT 'R'                                                    ||
                         TO_CHAR(N.DTEMISSAO,'DDMMYYYY')                        || /*Data de Emissao*/
                         SUBSTR(LPAD(N.NRNOTAFISC,20,'0'),13,8)                 || /*Nmero do Documento Recebido*/
                         RPAD(' ',8,' ')                                        || /*Brancos*/
                         N.CDTIPODOC                                            || /*Tipo Documento: 1-NF; 2-Recibo; 3-RPA; 4-ECF; 5-Outros; 6-NFCT*/
                         RPAD(NVL(N.CDSERIE,' '),3,' ')                         || /*Srie - somente NF*/
                         DECODE(N.VRISSRET,0,'N','S')                           || /*Identificao do Servio: S-Servio ST/Ret; N-Doc. Fiscal Normal*/
                         DECODE(N.CDMUNIORIG,N.CDMUNIDEST,'D','F')              || /*Local de Prestao - somente Servio ST/Ret*/
                         RPAD(NVL(SUBSTR(C.CDCLASSERVPADR,1,2),' '),2,' ')      || /*Cdigo Item - somente Servio ST/Ret*/
                         RPAD(NVL(SUBSTR(C.CDCLASSERVPADR,3,2),' '),2,' ')      || /*Cdito Sub-Item - somente Servio ST/Ret*/
                         LPAD(REPLACE(ROUND(SUM(NVL(N.VRCONTITEM,0)),2),',',''),15,'0')|| /*Valor Documento*/
                         LPAD('0',15,'0')                                       || /*Valor Deduo*/
                         LPAD(NVL(N.NRINSCMUNI,'0'),10,'0')                     || /*Insc. Municipal do tomador*/
                         LPAD(DECODE(N.IDTIPOJUR,'J',N.NRINSCJUR,'0'),14,'0')   || /*CNPJ do tomador*/
                         LPAD(DECODE(N.IDTIPOJUR,'F',N.NRINSCJUR,'0'),11,'0')   || /*CPF do tomador*/
                         RPAD(NVL(N.NMRAZSOC,' '),100,' ')                      || /*Nome do tomador*/
                         '     '                                                || /*Tipo Logradouro do endereo do tomador*/
                         RPAD(NVL(N.DSLOGRAD,' '),50,' ')                       || /*Nome Logradouro do endereo do tomador*/
                         '000000'                                               || /*Nmero do endereo do tomador*/
                         RPAD(NVL(N.DSCOMPLE,' '),20,' ')                       || /*Complemento do endereo do tomador*/
                         RPAD(NVL(N.NMBAIRRO,' '),50,' ')                       || /*Bairro do endereo do tomador*/
                         RPAD(NVL(N.NMMUNICIPIO,' '),44,' ')                    || /*Cidade do endereo do tomador*/
                         N.SGESTADO                                             || /*Estado do endereo do tomador*/
                         LPAD(REPLACE(NVL(N.CEP,'0'),'-',''),8,'0')             || /*CEP do endereo do tomador*/
                         LPAD(V_CONTADOR,6,'0')                                 || /*Sequencial*/
                         LPAD(REPLACE(ROUND(NVL(DECODE(N.VRISSRET,0,0,N.ALIQISSRET),0),2),',',''),4,'0') || /*Alquota*/
                         '.'                                                     AS DADOS, /*Indicador de final do arquivo*/
                         SUM(NVL(N.VRCONTITEM,0)) AS VRCONTITEM, N.VRNOTAFISC, N.NRLANCTONF, N.CDFILIAL
                    FROM CODTRIBPRODPADR C,
                         (SELECT NF.CDFILIAL, NF.NRLANCTONF, NF.DTEMISSAO, NF.NRNOTAFISC, NF.CDSERIE, NF.VRNOTAFISC, EN.SGESTADO||EN.CDMUNICIPIO AS CDMUNIORIG,
                                 CASE WHEN NF.CDMODDOCFISC = '2D' THEN '4' WHEN NF.CDMODDOCFISC IN ('08','09','10','11','26','57') THEN '6' ELSE '1' END AS CDTIPODOC,
                                 FO.NRINSMUNFORN AS NRINSCMUNI, FO.IDTPIJURFORN AS IDTIPOJUR, FO.NRINSJURFORN AS NRINSCJUR, FO.NMRAZSOCFORN AS NMRAZSOC,
                                 EF.DSENDEFORN AS DSLOGRAD, EF.DSCOMPENDFOR AS DSCOMPLE, EF.NMBAIRFORN AS NMBAIRRO, MP.NMMUNICIPIO, EF.SGESTADO, EF.NRCEPFORN AS CEP,
                                 EF.SGESTADO||EF.CDMUNICIPIO AS CDMUNIDEST, NF.CDEMPRESA, NF.CDINSCMUNI, IP.CDPRODUTO,
                                 SUM(VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL,IT.NRLANCTONF,IT.NRSEQITPROD,'35','C','1')) AS VRCONTITEM,
                                 SUM(VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL,IT.NRLANCTONF,IT.NRSEQITPROD,'35','I','1')) AS VRISSRET,
                                 VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL,IT.NRLANCTONF,IT.NRSEQITPROD,'35','A','1') AS ALIQISSRET
                            FROM LISTA LS, NOTAFISCAL NF, ENDEFILI EN, FORNECEDOR FO, ENDEFORN EF, MUNICIPIO MP, ITEMPROIMPOS IT, ITEMPRODUTO IP
                           WHERE LS.NRLISTA      = P_NRLISTA
                             AND LS.CDLISTA      = NF.CDFILIAL||NF.NRLANCTONF
                             AND NF.IDSTATUSNFE <> 'C'
                             AND NF.IDENTRSAIDOP = 'E'
                             AND NF.CDFILIRECE   = EN.CDFILIAL
                             AND NVL(EN.IDTPENDEFILI,'P') = 'P'
                             AND NF.IDORIGDESTNF = 'F'
                             AND NF.CDFORNECED   = FO.CDFORNECED(+)
                             AND FO.CDFORNECED   = EF.CDFORNECED(+)
                             AND NVL(EF.IDTPENDEFORN(+),'P') = 'P'
                             AND EF.CDPAIS       = MP.CDPAIS(+)
                             AND EF.SGESTADO     = MP.SGESTADO(+)
                             AND EF.CDMUNICIPIO  = MP.CDMUNICIPIO(+)
                             AND NF.CDFILIAL     = IT.CDFILIAL
                             AND NF.NRLANCTONF   = IT.NRLANCTONF
                             AND IT.CDFILIAL     = IP.CDFILIAL
                             AND IT.NRLANCTONF   = IP.NRLANCTONF
                             AND IT.NRSEQITPROD  = IP.NRSEQITPROD
                           GROUP BY NF.CDFILIAL, NF.NRLANCTONF, NF.DTEMISSAO, NF.NRNOTAFISC, NF.CDSERIE, NF.VRNOTAFISC, EN.SGESTADO||EN.CDMUNICIPIO,
                                 CASE WHEN NF.CDMODDOCFISC = '2D' THEN '4' WHEN NF.CDMODDOCFISC IN ('08','09','10','11','26','57') THEN '6' ELSE '1' END,
                                 FO.NRINSMUNFORN, FO.IDTPIJURFORN, FO.NRINSJURFORN, FO.NMRAZSOCFORN, NF.CDEMPRESA, NF.CDINSCMUNI, IP.CDPRODUTO,
                                 EF.DSENDEFORN, EF.DSCOMPENDFOR, EF.NMBAIRFORN, MP.NMMUNICIPIO, EF.SGESTADO, EF.NRCEPFORN, EF.SGESTADO||EF.CDMUNICIPIO,
                                 VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL,IT.NRLANCTONF,IT.NRSEQITPROD,'35','A','1')
                          UNION ALL
                          SELECT NF.CDFILIAL, NF.NRLANCTONF, NF.DTEMISSAO, NF.NRNOTAFISC, NF.CDSERIE, NF.VRNOTAFISC, EN.SGESTADO||EN.CDMUNICIPIO,
                                 CASE WHEN NF.CDMODDOCFISC = '2D' THEN '4' WHEN NF.CDMODDOCFISC IN ('08','09','10','11','26','57') THEN '6' ELSE '1' END AS CDTIPODOC,
                                 FI.CDINSCMUNI AS NRINSCMUNI, FI.IDTPIJURFILI AS IDTIPOJUR, FI.NRINSJURFILI AS NRINSCJUR, FI.NMRAZSOCFILI AS NMRAZSOC,
                                 EL.DSENDEFILI AS DSLOGRAD, EL.DSCOMPENDFIL AS DSCOMPLE, EL.NMBAIRFILI AS NMBAIRRO, MP.NMMUNICIPIO, EL.SGESTADO, EL.NRCEPFILI AS CEP,
                                 EL.SGESTADO||EL.CDMUNICIPIO AS CDMUNIDEST, NF.CDEMPRESA, NF.CDINSCMUNI, IP.CDPRODUTO,
                                 SUM(VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL,IT.NRLANCTONF,IT.NRSEQITPROD,'35','C','1')) AS VRCONTITEM,
                                 SUM(VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL,IT.NRLANCTONF,IT.NRSEQITPROD,'35','I','1')) AS VRISSRET,
                                 VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL,IT.NRLANCTONF,IT.NRSEQITPROD,'35','A','1') AS ALIQISSRET
                            FROM LISTA LS, NOTAFISCAL NF, ENDEFILI EN, FILIAL FI, ENDEFILI EL, MUNICIPIO MP, ITEMPROIMPOS IT, ITEMPRODUTO IP
                           WHERE LS.NRLISTA      = P_NRLISTA
                             AND LS.CDLISTA      = NF.CDFILIAL||NF.NRLANCTONF
                             AND NF.IDSTATUSNFE <> 'C'
                             AND NF.IDENTRSAIDOP = 'E'
                             AND NF.CDFILIRECE   = EN.CDFILIAL
                             AND NVL(EN.IDTPENDEFILI,'P') = 'P'
                             AND NF.IDORIGDESTNF = 'L'
                             AND NF.CDFILIEMIT   = FI.CDFILIAL(+)
                             AND FI.CDFILIAL     = EL.CDFILIAL(+)
                             AND NVL(EL.IDTPENDEFILI(+),'P') = 'P'
                             AND EL.CDPAIS       = MP.CDPAIS(+)
                             AND EL.SGESTADO     = MP.SGESTADO(+)
                             AND EL.CDMUNICIPIO  = MP.CDMUNICIPIO(+)
                             AND NF.CDFILIAL     = IT.CDFILIAL
                             AND NF.NRLANCTONF   = IT.NRLANCTONF
                             AND IT.CDFILIAL     = IP.CDFILIAL
                             AND IT.NRLANCTONF   = IP.NRLANCTONF
                             AND IT.NRSEQITPROD  = IP.NRSEQITPROD
                           GROUP BY NF.CDFILIAL, NF.NRLANCTONF, NF.DTEMISSAO, NF.NRNOTAFISC, NF.CDSERIE, NF.VRNOTAFISC, EN.SGESTADO||EN.CDMUNICIPIO,
                                 CASE WHEN NF.CDMODDOCFISC = '2D' THEN '4' WHEN NF.CDMODDOCFISC IN ('08','09','10','11','26','57') THEN '6' ELSE '1' END,
                                 FI.CDINSCMUNI, FI.IDTPIJURFILI, FI.NRINSJURFILI, FI.NMRAZSOCFILI, NF.CDEMPRESA, NF.CDINSCMUNI, IP.CDPRODUTO,
                                 EL.DSENDEFILI, EL.DSCOMPENDFIL, EL.NMBAIRFILI, MP.NMMUNICIPIO, EL.SGESTADO, EL.NRCEPFILI, EL.SGESTADO||EL.CDMUNICIPIO,
                                 VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL,IT.NRLANCTONF,IT.NRSEQITPROD,'35','A','1')) N
                   WHERE N.CDEMPRESA  = C.CDEMPRESA(+)
                     AND N.CDINSCMUNI = C.CDINSCMUNI(+)
                     AND N.CDPRODUTO  = C.CDPRODUTO(+)
                   GROUP BY 'R',
                            TO_CHAR(N.DTEMISSAO,'DDMMYYYY'),
                            N.NRNOTAFISC,
                            N.CDTIPODOC,
                            N.CDSERIE,
                            DECODE(N.VRISSRET,0,'N','S'),
                            DECODE(N.CDMUNIORIG,N.CDMUNIDEST,'D','F'),
                            SUBSTR(C.CDCLASSERVPADR,1,2),
                            SUBSTR(C.CDCLASSERVPADR,3,2),
                            N.NRINSCMUNI,
                            DECODE(N.IDTIPOJUR,'J',N.NRINSCJUR,'0'),
                            DECODE(N.IDTIPOJUR,'F',N.NRINSCJUR,'0'),
                            N.NMRAZSOC,
                            N.DSLOGRAD,
                            N.DSCOMPLE,
                            N.NMBAIRRO,
                            N.NMMUNICIPIO,
                            N.SGESTADO,
                            N.CEP,
                            V_CONTADOR,
                            DECODE(N.VRISSRET,0,0,N.ALIQISSRET),
                            N.VRNOTAFISC, N.NRLANCTONF, N.CDFILIAL
                   ORDER BY N.NRNOTAFISC) LOOP

      INSERT INTO ARQMAGNETICO
         (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
       VALUES
         ('4'||LPAD(V_CONTADOR,9,'0'), C_REGR.DADOS , P_NRSEQARQMAG);
      V_CONTADOR := NVL(V_CONTADOR,0)+1;

      V_VRTOTRECE := NVL(V_VRTOTRECE,0) + C_REGR.VRCONTITEM;
      V_VRDEDRECE := 0;

      UPDATE NOTAFISCAL
         SET IDEXPNFEISS = 'S'
       WHERE CDFILIAL    = C_REGR.CDFILIAL
         AND NRLANCTONF  = C_REGR.NRLANCTONF;

   END LOOP;

   /*REGISTRO TRAILLER*/
   V_CONTADOR := NVL(V_CONTADOR,0)+1;
   
   SELECT 'T'                                                     ||
          LPAD(V_CONTADOR,8,'0')                                  || /*Total de registros do arquivo*/
          LPAD(REPLACE(ROUND(NVL(V_VRTOTEMIT,0),2),',',''),15,'0')|| /*Valor total dos documentos emitidos - E11*/
          LPAD(REPLACE(ROUND(NVL(V_VRDEDEMIT,0),2),',',''),15,'0')|| /*Total das dedues dos documentos emitidos - E12*/
          LPAD(REPLACE(ROUND(NVL(V_VRTOTRECE,0),2),',',''),15,'0')|| /*Valor total dos documentos recebidos - R11*/
          LPAD(REPLACE(ROUND(NVL(V_VRDEDRECE,0),2),',',''),15,'0')|| /*Total das dedues dos documentos recebidos - R12*/
          RPAD(' ',326,' ')                                       || /*Brancos*/
          '.'                                                        /*Indicador de final do arquivo*/
     INTO V_REGT
     FROM DUAL;

   INSERT INTO ARQMAGNETICO
      (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
    VALUES
      ('5'||LPAD(V_CONTADOR,9,'0'), V_REGT, P_NRSEQARQMAG);

END;
/